@@ -1,4 +1,11 @@
 package Tapper::Config;
+BEGIN {
+  $Tapper::Config::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Config::VERSION = '4.0.1';
+}
+# ABSTRACT: Tapper - Context sensitive configuration hub for all Tapper libs
 
 use 5.010;
 
@@ -11,36 +18,6 @@ use File::ShareDir      'module_file';
 use Hash::Merge::Simple 'merge';
 use File::ShareDir 'module_file';
 
-=head1 NAME
-
-Tapper::Config - Tapper - Context sensitive configuration hub for all Tapper libs
-
-=cut
-
-our $VERSION = '3.000010';
-
-=head1 SYNOPSIS
-
- use Tapper::Config;
- say Tapper::Config->subconfig->{test_value};
- say Tapper::Config->subconfig->{paths}{build_conf_path};
-
-
-=head1 AUTHOR
-
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
-
-=head1 ACKNOWLEDGEMENTS
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
-
-
-=cut
 
 # --- The configuration file is lib/auto/Tapper/Config/tapper.yml ---
 {
@@ -49,34 +26,18 @@ This program is released under the following license: freebsd
 
 
 
-=head2 default_merge
-
-Merges default values from /etc/tapper into the config. This allows to
-overwrite values given from the config provided with the module. It
-searches for config in the following places.
-* filename given in $ENV{TAPPER_CONFIG_FILE}
-* $ENV{HOME}/.tapper.cfg
-* /etc/tapper.cfg
-
-If $ENV{TAPPER_CONFIG_FILE} exists it will be used no mather if it
-contains an existing file. If this key does not exists the first file
-found from the list of remaining alternatives is used.
-
-@param hash ref - config
-
-@return hash ref - merged config
-
-=cut
-
         sub default_merge
         {
                 my ($config) = @_;
                 my $new_config;
+                no warnings 'uninitialized'; # $ENV{HOME} can be undef
                 if (exists $ENV{TAPPER_CONFIG_FILE}) {
+                        my $env_config_file = $ENV{TAPPER_CONFIG_FILE} || "";
+                        die "Config file '$env_config_file' does not exist.\n" unless -r $env_config_file;
                         eval {
-                                $new_config = LoadFile($ENV{TAPPER_CONFIG_FILE});
+                                $new_config = LoadFile($env_config_file);
                         };
-                        die "Can not load config file '$ENV{TAPPER_CONFIG_FILE}': $@\n" if $@;
+                        die "Can not load config file '$env_config_file': $@\n" if $@;
                 } elsif ( -e "$ENV{HOME}/.tapper.cfg" ) {
                                 $new_config = LoadFile("$ENV{HOME}/.tapper.cfg");
                 } elsif ( -e "/etc/tapper.cfg" ) {
@@ -132,3 +93,54 @@ BEGIN { _switch_context() }
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Config - Tapper - Context sensitive configuration hub for all Tapper libs
+
+=head1 SYNOPSIS
+
+ use Tapper::Config;
+ say Tapper::Config->subconfig->{test_value};
+ say Tapper::Config->subconfig->{paths}{build_conf_path};
+
+=head2 default_merge
+
+Merges default values from /etc/tapper into the config. This allows to
+overwrite values given from the config provided with the module. It
+searches for config in the following places.
+* filename given in $ENV{TAPPER_CONFIG_FILE}
+* $ENV{HOME}/.tapper.cfg
+* /etc/tapper.cfg
+
+If $ENV{TAPPER_CONFIG_FILE} exists it will be used no mather if it
+contains an existing file. If this key does not exists the first file
+found from the list of remaining alternatives is used.
+
+@param hash ref - config
+
+@return hash ref - merged config
+
+=head2 subconfig
+
+Return the actual config for the current context.
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
